@@ -446,6 +446,7 @@ class StackHandler:
             True if everything went well, False otherwise
         """
         subprocess.run("docker compose down --volumes".split(), cwd=self.__docker_path_of_user, check=True)
-        with contextlib.suppress(PermissionError):  # in GitHub CI, python lacks permissions to delete this dir
-            shutil.rmtree(self.__docker_path_of_user / "sipi")
+        shutil.rmtree(self.__docker_path_of_user / "sipi", ignore_errors=True)
+        # ignore all errors, because the dir cannot be found if this function is called multiple times,
+        # and because in GitHub CI, python lacks permissions to delete this dir
         return True
