@@ -33,10 +33,8 @@ def authentication(creds: ServerCredentials) -> AuthenticationClient:
 @pytest.mark.usefixtures("create_generic_project")
 def test_minimal_correct(authentication) -> None:
     file = Path("testdata/validate-data/generic/minimal_correct.xml")
-    graphs, used_iris = prepare_data_for_validation_from_file(
-        file, authentication, CONFIG.ignore_duplicate_files_warning
-    )
-    validation_result = _validate_data(graphs, used_iris, CONFIG)
+    graphs, used_iris, parsed_resource = prepare_data_for_validation_from_file(file, authentication)
+    validation_result = _validate_data(graphs, used_iris, parsed_resource, CONFIG)
     assert validation_result.no_problems
     assert not validation_result.problems
     assert not validation_result.report_graphs
@@ -45,10 +43,8 @@ def test_minimal_correct(authentication) -> None:
 @pytest.mark.usefixtures("create_generic_project")
 def test_cardinality_correct(authentication, shacl_validator: ShaclCliValidator) -> None:
     file = Path("testdata/validate-data/generic/cardinality_correct.xml")
-    graphs, used_iris = prepare_data_for_validation_from_file(
-        file, authentication, CONFIG.ignore_duplicate_files_warning
-    )
-    validation_result = _validate_data(graphs, used_iris, CONFIG)
+    graphs, used_iris, parsed_resource = prepare_data_for_validation_from_file(file, authentication)
+    validation_result = _validate_data(graphs, used_iris, parsed_resource, CONFIG)
     assert validation_result.no_problems
     assert not validation_result.problems
     assert not validation_result.report_graphs
@@ -57,10 +53,8 @@ def test_cardinality_correct(authentication, shacl_validator: ShaclCliValidator)
 @pytest.mark.usefixtures("create_generic_project")
 def test_content_correct(authentication, shacl_validator: ShaclCliValidator) -> None:
     file = Path("testdata/validate-data/generic/content_correct.xml")
-    graphs, used_iris = prepare_data_for_validation_from_file(
-        file, authentication, CONFIG.ignore_duplicate_files_warning
-    )
-    validation_result = _validate_data(graphs, used_iris, CONFIG)
+    graphs, used_iris, parsed_resource = prepare_data_for_validation_from_file(file, authentication)
+    validation_result = _validate_data(graphs, used_iris, parsed_resource, CONFIG)
     assert validation_result.no_problems
     assert not validation_result.problems
     assert not validation_result.report_graphs
@@ -69,10 +63,8 @@ def test_content_correct(authentication, shacl_validator: ShaclCliValidator) ->
 @pytest.mark.usefixtures("create_generic_project")
 def test_file_value_correct(authentication, shacl_validator: ShaclCliValidator) -> None:
     file = Path("testdata/validate-data/generic/file_value_correct.xml")
-    graphs, used_iris = prepare_data_for_validation_from_file(
-        file, authentication, CONFIG.ignore_duplicate_files_warning
-    )
-    validation_result = _validate_data(graphs, used_iris, CONFIG)
+    graphs, used_iris, parsed_resource = prepare_data_for_validation_from_file(file, authentication)
+    validation_result = _validate_data(graphs, used_iris, parsed_resource, CONFIG)
     assert validation_result.no_problems
     assert not validation_result.problems
     assert not validation_result.report_graphs
@@ -81,10 +73,8 @@ def test_file_value_correct(authentication, shacl_validator: ShaclCliValidator)
 @pytest.mark.usefixtures("create_generic_project")
 def test_dsp_inbuilt_correct(authentication, shacl_validator: ShaclCliValidator) -> None:
     file = Path("testdata/validate-data/generic/dsp_inbuilt_correct.xml")
-    graphs, used_iris = prepare_data_for_validation_from_file(
-        file, authentication, CONFIG.ignore_duplicate_files_warning
-    )
-    validation_result = _validate_data(graphs, used_iris, CONFIG)
+    graphs, used_iris, parsed_resource = prepare_data_for_validation_from_file(file, authentication)
+    validation_result = _validate_data(graphs, used_iris, parsed_resource, CONFIG)
     assert validation_result.no_problems
     assert not validation_result.problems
     assert not validation_result.report_graphs
