@@ -167,7 +167,8 @@ class TestCreateGetXMLUpload(unittest.TestCase):
             project_original: original file
             project_returned: returned file
         """
-        for field in ["shortcode", "shortname", "longname", "descriptions"]:
+        self.assertListEqual(list(project_original.keys()), list(project_returned.keys()))
+        for field in ["shortcode", "shortname", "longname", "descriptions", "default_permissions"]:
             orig = project_original["project"].get(field)
             ret = project_returned["project"].get(field)
             self.assertEqual(orig, ret, msg=f"Field '{field}' is not identical: original='{orig}', returned='{ret}'")
