@@ -7,6 +7,7 @@ from rdflib import SH
 from rdflib import XSD
 from rdflib import Graph
 from rdflib import Literal
+from rdflib import URIRef
 
 from dsp_tools.commands.validate_data.models.input_problems import ProblemType
 from dsp_tools.commands.validate_data.models.input_problems import Severity
@@ -344,6 +345,21 @@ class TestQueryWithoutDetail:
         assert result.severity == SH.Violation
         assert result.message == Literal("The property seqnum must be used together with isPartOf")
         assert not result.property
+        assert not result.input_value
+
+    def test_report_coexist_with_date(
+        self, report_coexist_with_date: tuple[Graph, Graph, ValidationResultBaseInfo]
+    ) -> None:
+        validation_g, data, info = report_coexist_with_date
+        result = _query_one_without_detail(info, validation_g, data)
+        assert isinstance(result, ValidationResult)
+        assert result.violation_type == ViolationType.GENERIC
+        assert result.res_iri == info.focus_node_iri
+        assert result.res_class == info.focus_node_type
+        assert result.severity == SH.Violation
+        assert result.message == Literal("date message")
+        assert result.property == info.result_path
+        assert result.input_value == Literal("GREGORIAN:CE:2000:BCE:1900", datatype=XSD.string)
 
     def test_image_missing_legal_info(
         self, report_image_missing_legal_info: tuple[Graph, Graph, ValidationResultBaseInfo]
@@ -409,7 +425,42 @@ Second Line"""
         assert result.property == ONTO.testSubDate1
         assert result.severity == SH.Violation
         assert result.message == Literal("date message")
-        assert result.input_value == Literal("1800-22")
+        assert result.input_value == Literal("GREGORIAN:CE:1800-22", datatype=XSD.string)
+
+    def test_report_date_range_wrong_yyyy(
+        self, report_date_range_wrong_yyyy: tuple[Graph, Graph, ValidationResultBaseInfo]
+    ) -> None:
+        res, data, info = report_date_range_wrong_yyyy
+        result = _query_one_without_detail(info, res, data)
+        assert isinstance(result, ValidationResult)
+        assert result.violation_type == ViolationType.GENERIC
+        assert result.res_iri == info.focus_node_iri
+        assert result.res_class == info.focus_node_type
+        assert result.property == ONTO.testSubDate1
+        assert result.severity == SH.Violation
+        assert result.message == Literal("date message")
+        assert result.input_value == Literal("GREGORIAN:CE:2000:CE:1900", datatype=XSD.string)
+
+    def test_report_date_range_wrong_to_ignore(
+        self, report_date_range_wrong_to_ignore: tuple[Graph, Graph, ValidationResultBaseInfo]
+    ) -> None:
+        res, data, info = report_date_range_wrong_to_ignore
+        result = _query_one_without_detail(info, res, data)
+        assert not result
+
+    def test_report_standoff_link_target_is_iri(
+        self, report_standoff_link_target_is_iri: tuple[Graph, Graph, ValidationResultBaseInfo]
+    ) -> None:
+        res, data, info = report_standoff_link_target_is_iri
+        result = _query_one_without_detail(info, res, data)
+        assert isinstance(result, ValidationResult)
+        assert result.violation_type == ViolationType.LINK_TARGET
+        assert result.res_iri == info.focus_node_iri
+        assert result.res_class == info.focus_node_type
+        assert result.property == KNORA_API.hasStandoffLinkTo
+        assert result.severity == SH.Violation
+        assert result.message == Literal("A stand-off link must target an existing resource.")
+        assert result.input_value == URIRef("http://rdfh.ch/4123/DiAmYQzQSzC7cdTo6OJMYA")
 
     def test_unknown(self, result_unknown_component: tuple[Graph, ValidationResultBaseInfo]) -> None:
         graphs, info = result_unknown_component
